Learn R Programming

ReAD (version 1.0.1)

em_hmm: EM algorithm in combination with a non-parametric algorithm for estimation of the rLIS statistic.

Description

Estimate the rLIS values accounting for the linkage disequilibrium across two genome-wide association studies via the four-state hidden Markov model. Apply a step-up procedure to control the FDR of replicability null.

Usage

em_hmm(pa_in, pb_in, pi0a_in, pi0b_in)

Value

rLIS

The estimated rLIS for replicability null.

fdr

The adjusted values based on rLIS for FDR control.

loglik

The log-likelihood value with converged estimates of the unknowns.

pi

An estimate of the stationary probabilities of four states (0,0), (0,1), (1,0), (1,1).

A

An estimate of the 4-by-4 transition matrix.

f1

A non-parametric estimate for the non-null probability density function in study 1.

f2

A non-parametric estimate for the non-null probability density function in study 2.

Arguments

pa_in

A numeric vector of p-values from study 1.

pb_in

A numeric vector of p-values from study 2.

pi0a_in

An initial estimate of the null probability in study 1.

pi0b_in

An initial estimate of the null probability in study 2.