Estimate the rLIS values accounting for the linkage disequilibrium across two genome-wide association studies via the four-state hidden Markov model. Apply a step-up procedure to control the FDR of replicability null.
em_hmm(pa_in, pb_in, pi0a_in, pi0b_in)The estimated rLIS for replicability null.
The adjusted values based on rLIS for FDR control.
The log-likelihood value with converged estimates of the unknowns.
An estimate of the stationary probabilities of four states (0,0), (0,1), (1,0), (1,1).
An estimate of the 4-by-4 transition matrix.
A non-parametric estimate for the non-null probability density function in study 1.
A non-parametric estimate for the non-null probability density function in study 2.
A numeric vector of p-values from study 1.
A numeric vector of p-values from study 2.
An initial estimate of the null probability in study 1.
An initial estimate of the null probability in study 2.